#[cfg(wasm)]
pub mod browser;
pub mod context;
pub mod fmt;
pub mod hiscore;
pub mod http;
pub mod item;
pub mod math;
pub mod skill;
pub mod table;
